@@ -1,5 +1,25 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
 """Filtering of :math:`B_0` field mappings with B-Splines."""
 from pathlib import Path
 from functools import partial
@@ -251,8 +271,6 @@ class ApplyCoeffsField(SimpleInterface):
             pe_dir = [pe_dir[0]] * n_inputs
 
         for fname, pe, ro in zip(self.inputs.in_target, pe_dir, ro_time):
-            xfm.fit(fname)
-
             # Generate warpfield
             warp_name = filename(fname, suffix="_xfm")
             xfm.to_displacements(ro_time=ro, pe_dir=pe).to_filename(warp_name)
@@ -443,7 +461,5 @@ def _fix_topup_fieldcoeff(in_coeff, fmap_ref, refpe_reversed=False, out_file=Non
     coeffnii.header.set_qform(coeffnii.header.get_qform(coded=False), code=0)
     coeffnii.header.set_sform(newaff, code=1)
 
-    # If the reference is reversed encoded, flip the displacements
-    coeffs = (1.0 - 2.0 * refpe_reversed) * np.asanyarray(coeffnii.dataobj)
-    coeffnii.__class__(coeffs, newaff, header).to_filename(out_file)
+    coeffnii.__class__(coeffnii.dataobj, newaff, header).to_filename(out_file)
     return out_file
